@@ -1,14 +1,12 @@
 #!/usr/bin/env python
 
-"""
-Settings for the comparable.test package.
-"""
+"""Settings for the comparable.test package."""
 
 import logging
 
 DEFAULT_LOGGING_FORMAT = "%(message)s"
 VERBOSE_LOGGING_FORMAT = "%(levelname)s: %(message)s"
 VERBOSE2_LOGGING_FORMAT = "%(asctime)s: %(levelname)s: %(message)s"
-VERBOSE3_LOGGING_FORMAT = "%(asctime)s: %(levelname)s: %(module)s:%(lineno)d: %(message)s"
+VERBOSE3_LOGGING_FORMAT = "%(asctime)s: %(levelname)s: %(module)s:%(lineno)d: %(message)s"  # pylint: disable=C0301
 DEFAULT_LOGGING_LEVEL = logging.INFO
 VERBOSE_LOGGING_LEVEL = logging.DEBUG
